aboutsummaryrefslogtreecommitdiff
path: root/ld
diff options
context:
space:
mode:
Diffstat (limited to 'ld')
-rw-r--r--ld/ChangeLog13
-rw-r--r--ld/ldelfgen.c4
-rw-r--r--ld/ldelfgen.h4
-rw-r--r--ld/ldemul.c2
-rw-r--r--ld/ldemul.h4
-rw-r--r--ld/ldlang.c10
6 files changed, 25 insertions, 12 deletions
diff --git a/ld/ChangeLog b/ld/ChangeLog
index c0b47f4..a00cfe9 100644
--- a/ld/ChangeLog
+++ b/ld/ChangeLog
@@ -1,3 +1,16 @@
+2020-11-20 Nick Alcock <nick.alcock@oracle.com>
+
+ * ldlang.c (ctf_output): This is a ctf_dict_t now.
+ (lang_ctf_errs_warnings): Rename ctf_file_t to ctf_dict_t.
+ (ldlang_open_ctf): Adjust comment.
+ (lang_merge_ctf): Use ctf_dict_close, not ctf_file_close.
+ * ldelfgen.h (ldelf_examine_strtab_for_ctf): Rename ctf_file_t to
+ ctf_dict_t. Change opaque declaration accordingly.
+ * ldelfgen.c (ldelf_examine_strtab_for_ctf): Adjust.
+ * ldemul.h (examine_strtab_for_ctf): Likewise.
+ (ldemul_examine_strtab_for_ctf): Likewise.
+ * ldeuml.c (ldemul_examine_strtab_for_ctf): Likewise.
+
2020-11-20 Jozef Lawrynowicz <jozef.l@mittosystems.com>
* testsuite/ld-elf/retain3.s: Move symbolic reference into writeable
diff --git a/ld/ldelfgen.c b/ld/ldelfgen.c
index 3a56194..e9496f9 100644
--- a/ld/ldelfgen.c
+++ b/ld/ldelfgen.c
@@ -175,7 +175,7 @@ ldelf_ctf_symbols_iter_cb (struct ctf_link_sym *dest,
void
ldelf_examine_strtab_for_ctf
- (struct ctf_file *ctf_output, struct elf_sym_strtab *syms,
+ (struct ctf_dict *ctf_output, struct elf_sym_strtab *syms,
bfd_size_type symcount, struct elf_strtab_hash *symstrtab)
{
struct ctf_strsym_iter_cb_arg args = { syms, symcount, symstrtab,
@@ -205,7 +205,7 @@ extern int ldelf_emit_ctf_early (void)
}
extern void ldelf_examine_strtab_for_ctf
- (struct ctf_file *ctf_output ATTRIBUTE_UNUSED,
+ (struct ctf_dict *ctf_output ATTRIBUTE_UNUSED,
struct elf_sym_strtab *syms ATTRIBUTE_UNUSED,
bfd_size_type symcount ATTRIBUTE_UNUSED,
struct elf_strtab_hash *symstrtab ATTRIBUTE_UNUSED)
diff --git a/ld/ldelfgen.h b/ld/ldelfgen.h
index 7079990..93bdf29 100644
--- a/ld/ldelfgen.h
+++ b/ld/ldelfgen.h
@@ -20,10 +20,10 @@
struct elf_sym_strtab;
struct elf_strtab_hash;
-struct ctf_file;
+struct ctf_dict;
extern void ldelf_map_segments (bfd_boolean);
extern int ldelf_emit_ctf_early (void);
extern void ldelf_examine_strtab_for_ctf
- (struct ctf_file *ctf_output, struct elf_sym_strtab *syms,
+ (struct ctf_dict *ctf_output, struct elf_sym_strtab *syms,
bfd_size_type symcount, struct elf_strtab_hash *symstrtab);
diff --git a/ld/ldemul.c b/ld/ldemul.c
index 00a6a5a..6dc5112 100644
--- a/ld/ldemul.c
+++ b/ld/ldemul.c
@@ -418,7 +418,7 @@ ldemul_emit_ctf_early (void)
}
void
-ldemul_examine_strtab_for_ctf (struct ctf_file *ctf_output,
+ldemul_examine_strtab_for_ctf (struct ctf_dict *ctf_output,
struct elf_sym_strtab *syms,
bfd_size_type symcount,
struct elf_strtab_hash *symstrtab)
diff --git a/ld/ldemul.h b/ld/ldemul.h
index ca165ac..5efe4aa 100644
--- a/ld/ldemul.h
+++ b/ld/ldemul.h
@@ -110,7 +110,7 @@ extern int ldemul_emit_ctf_early
(void);
/* Called from per-target code to examine the strtab and symtab. */
extern void ldemul_examine_strtab_for_ctf
- (struct ctf_file *, struct elf_sym_strtab *, bfd_size_type,
+ (struct ctf_dict *, struct elf_sym_strtab *, bfd_size_type,
struct elf_strtab_hash *);
extern bfd_boolean ldemul_print_symbol
(struct bfd_link_hash_entry *hash_entry, void *ptr);
@@ -236,7 +236,7 @@ typedef struct ld_emulation_xfer_struct {
waits until 'late'. (Late mode needs explicit support at per-target link
time to get called at all). If set, called by ld when the examine_strtab
bfd_link_callback is invoked by per-target code. */
- void (*examine_strtab_for_ctf) (struct ctf_file *, struct elf_sym_strtab *,
+ void (*examine_strtab_for_ctf) (struct ctf_dict *, struct elf_sym_strtab *,
bfd_size_type, struct elf_strtab_hash *);
/* Called when printing a symbol to the map file. AIX uses this
diff --git a/ld/ldlang.c b/ld/ldlang.c
index 2073ac0..eaf90a6 100644
--- a/ld/ldlang.c
+++ b/ld/ldlang.c
@@ -131,7 +131,7 @@ struct lang_phdr *lang_phdr_list;
struct lang_nocrossrefs *nocrossref_list;
struct asneeded_minfo **asneeded_list_tail;
#ifdef ENABLE_LIBCTF
-static ctf_file_t *ctf_output;
+static ctf_dict_t *ctf_output;
#endif
/* Functions that traverse the linker script and might evaluate
@@ -3674,7 +3674,7 @@ open_input_bfds (lang_statement_union_type *s, enum open_bfd_mode mode)
/* Emit CTF errors and warnings. fp can be NULL to report errors/warnings
that happened specifically at CTF open time. */
static void
-lang_ctf_errs_warnings (ctf_file_t *fp)
+lang_ctf_errs_warnings (ctf_dict_t *fp)
{
ctf_next_t *i = NULL;
char *text;
@@ -3713,7 +3713,7 @@ ldlang_open_ctf (void)
{
asection *sect;
/* Incoming files from the compiler have a single ctf_file_t in them
(which is presented to us by the libctf API in a ctf_archive_t
wrapper): files derived from a previous relocatable link have a CTF
archive containing possibly many CTF files. */
@@ -3776,7 +3776,7 @@ lang_merge_ctf (void)
/* If the section was discarded, don't waste time merging. */
if (output_sect == NULL)
{
- ctf_file_close (ctf_output);
+ ctf_dict_close (ctf_output);
ctf_output = NULL;
LANG_FOR_EACH_INPUT_STATEMENT (file)
@@ -3882,7 +3882,7 @@ lang_write_ctf (int late)
}
/* This also closes every CTF input file used in the link. */
- ctf_file_close (ctf_output);
+ ctf_dict_close (ctf_output);
ctf_output = NULL;
LANG_FOR_EACH_INPUT_STATEMENT (file)
@@ -3713,7 +3713,7 @@ ldlang_open_ctf (void)
{
asection *sect;
- /* Incoming files from the compiler have a single ctf_file_t in them
+ /* Incoming files from the compiler have a single ctf_dict_t in them
(which is presented to us by the libctf API in a ctf_archive_t
wrapper): files derived from a previous relocatable link have a CTF